local GPIO = require "chips.gpio"
--NOTE: GPIO.Pin(pin, direction, revert)

local _M = {
	IO_STEP_TIME = 0.166, --second
	RESTORE_TIME = 3000,   --ms.
	DEFAULT_BLINK_STEPS = {false, false, false, true, true, true},

	----------------------------
	-- Board LED.
	----------------------------
	board_led = {
		drv = GPIO.Pin(906,"out"),
		state = "blink",
		--You can specify any blink steps for special case.
		--blink_steps = { false, false, false, true, true, true },
	},

	----------------------------
	-- Tally LEDs.
	----------------------------
	tally_leds = {
		--You can specify any blink steps for special case.
		--blink_steps = { false, false, false, true, true, true },
		[1] = { red = { drv = GPIO.Pin(960,"out") }, green = { drv = GPIO.Pin(961,"out") } },
		--GPIO.Pin(pin, direction, revert)
		[2] = { red = { drv = GPIO.Pin(962,"out",true) }, green = { drv = GPIO.Pin(963,"out",true) } }
	},

	----------------------------
	-- Reset(Restore factory) button
	----------------------------
	reset_button = {
		drv = GPIO.Pin(952,"in")
	},

	----------------------------
	-- On demo LED animation
	----------------------------
	on_demo = {
		on = "startup",
		stage_index = 1,
		stages = {
		--See below of this file:
		--	startup = {...},
		--	restore = {...},
		--	reset = {...},
		--	...
		}
	},

	----------------------------
	-- Signal indicator
	----------------------------
	signal = {
		--You can specify any blink steps for special case.
		--blink_steps = { false, false, false, true, true, true },

		tally_light_id = 1,       --Reuse the tally light, or
		-- drv = { red = GPIO.Pin(...),   --Specify a GPIO pin for red,
		--         green = GPIO.Pin(...)  --Specify a GPIO pin for green
		--         -- Or,
		--         any = GPIO.Pin(...)    --Any color (only one color case)
		-- },
		red = "off",
		green = "off"
	}
}

----------------------------------------------------------------

local ON = false
local OFF = true
local HOLD = "HOLD"

-- The LED animation when startup.
local demo = {}

--Round 1, green OFF red ON.
for i=1, #_M.tally_leds do
	table.insert(demo, {_M.tally_leds[i].red.drv, ON})
	table.insert(demo, {_M.tally_leds[i].green.drv, OFF})
	--Hold 1 step.
	table.insert(demo, {HOLD, 1})
end

--Round 2, green ON red OFF
for i=1, #_M.tally_leds do
	table.insert(demo, {_M.tally_leds[i].red.drv, OFF})
	table.insert(demo, {_M.tally_leds[i].green.drv, ON})
	--Hold 1 step.
	table.insert(demo, {HOLD, 1})
end

--Round 3, all OFF step by step.
for i=1, #_M.tally_leds do
	table.insert(demo, {_M.tally_leds[i].red.drv, OFF})
	table.insert(demo, {_M.tally_leds[i].green.drv, OFF})
	--Hold 1 step.
	table.insert(demo, {HOLD, 1})
end

_M.on_demo.stages["startup"] = demo

-- The LED animation when restore factory settings.
demo = {}
--Round 1, green ON red OFF.
for i=1, #_M.tally_leds do
	table.insert(demo, {_M.tally_leds[i].red.drv, OFF})
	table.insert(demo, {_M.tally_leds[i].green.drv, ON})
	--Hold 1 step.
	table.insert(demo, {HOLD, 1})
end

--Round 2, green OFF red ON
for i=1, #_M.tally_leds do
	table.insert(demo, {_M.tally_leds[i].red.drv, ON})
	table.insert(demo, {_M.tally_leds[i].green.drv, OFF})
	--Hold 1 step.
	table.insert(demo, {HOLD, 1})
end

--Round 3, all OFF step by step.
for i=1, #_M.tally_leds do
	table.insert(demo, {_M.tally_leds[i].red.drv, OFF})
	table.insert(demo, {_M.tally_leds[i].green.drv, OFF})
	--NOT HOLD.
	--table.insert(demo, {HOLD, 1})
end

_M.on_demo.stages["restore"] = demo

-- The LED animation when quick reset.
demo = {}
--Round 1, green ON red OFF.
for i=1, #_M.tally_leds do
	table.insert(demo, {_M.tally_leds[i].red.drv, OFF})
	table.insert(demo, {_M.tally_leds[i].green.drv, ON})
	--Hold 1 step.
	table.insert(demo, {HOLD, 1})
end

--Round 2, green OFF red ON.
for i=1, #_M.tally_leds do
	table.insert(demo, {_M.tally_leds[i].red.drv, ON})
	table.insert(demo, {_M.tally_leds[i].green.drv, OFF})
	--Hold 1 step.
	table.insert(demo, {HOLD, 1})
end

--Round 3, green ON red OFF.
for i=1, #_M.tally_leds do
	table.insert(demo, {_M.tally_leds[i].red.drv, OFF})
	table.insert(demo, {_M.tally_leds[i].green.drv, ON})
	--Hold 1 step.
	table.insert(demo, {HOLD, 1})
end

--Round 4, green OFF red ON.
for i=1, #_M.tally_leds do
	table.insert(demo, {_M.tally_leds[i].red.drv, ON})
	table.insert(demo, {_M.tally_leds[i].green.drv, OFF})
	--Hold 1 step.
	table.insert(demo, {HOLD, 1})
end
_M.on_demo.stages["reset"] = demo

return _M

